@@ -26,7 +26,7 @@ class GossClient(object):
         Initialize client
         """
         if ctype not in self.CLIENT_SUPPORTED_MAP:
-            raise GossException("OOS type about '{type}' does not supported".format_exc(type=ctype))
+            raise GossException("OOS type about '{type}' does not supported".format(type=ctype))
         self._client = self.CLIENT_SUPPORTED_MAP[ctype](secret_id, secret_key, region, bucket)
 
     def upload_file(self, local_path, cloud_path):
